Bugreports and Development
==============================

If you request new feautures or want to report bugs please open an issue on the `github project page <https://github.com/mcocdawc/chemcoord/issues>`_.

If you want to contribute in the development, feel free to contact me as well over the `github project page <https://github.com/mcocdawc/chemcoord/issues>`_.


Previous Contribution
==============================

* Main Work: Oskar Weser

* Scientific supervision: `Ricardo Mata <https://www.uni-goettingen.de/en/123801.html>`__

* Python2 compatibility: Keld Lundgaard

* Maintenance (Change in pandas API): Niccolo Ricardi

* Maintenance (Change in pandas API): `Mayank Goel <https://github.com/Mayank447>`__

* Packaging for `conda-forge <https://anaconda.org/conda-forge/chemcoord>`__: `Geoffrey R. Hutchison <https://github.com/ghutchis>`__
